==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/entity/ai/brain/task/MaidFindSitTask.java <==
package com.github.tartaricacid.touhoulittlemaid.entity.ai.brain.task;

import com.github.tartaricacid.touhoulittlemaid.entity.chatbubble.ChatBubbleManger;
import com.github.tartaricacid.touhoulittlemaid.entity.item.EntityChair;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.google.common.collect.ImmutableMap;
import net.minecraft.class_1297;
import net.minecraft.class_1690;
import net.minecraft.class_3218;
import net.minecraft.class_4140;
import net.minecraft.class_4141;
import net.minecraft.class_4215;
import net.minecraft.class_6670;

public class MaidFindSitTask extends MaidCheckRateTask {
    private static final int MAX_DELAY_TIME = 12;
    private final float speedModifier;
    private class_1297 sitEntity = null;

    public MaidFindSitTask(float speedModifier) {
        super(ImmutableMap.of(class_4140.field_18442, class_4141.field_18456,
                class_4140.field_18445, class_4141.field_18457));
        this.speedModifier = speedModifier;
        this.setMaxCheckRate(MAX_DELAY_TIME);
    }

    @Override
    protected boolean checkExtraStartConditions(class_3218 worldIn, EntityMaid owner) {
        return super.checkExtraStartConditions(worldIn, owner) && owner.method_5854() == null;
    }

    @Override
    protected void start(class_3218 worldIn, EntityMaid maid, long gameTimeIn) {
        this.sitEntity = null;
        this.getEntities(maid)
                .method_38980(e -> filterEntity(maid, e))
                .findFirst()
                .ifPresentOrElse(entity -> {
                    this.sitEntity = entity;
                    class_4215.method_24557(maid, this.sitEntity, this.speedModifier, 0);
                }, () -> ChatBubbleManger.addInnerChatText(maid, "chat_bubble.touhou_little_maid.inner.fishing.no_sit"));

        if (sitEntity != null && sitEntity.method_5805() && sitEntity.method_24516(maid, 2)) {
            if (sitEntity.method_5685().isEmpty()) {
                maid.method_5873(this.sitEntity, true);
            }
            this.sitEntity = null;
        }
    }

    private boolean filterEntity(EntityMaid maid, class_1297 entity) {
        if (!entity.method_5805()) {
            return false;
        }
        if (!maid.method_18407(entity.method_24515())) {
            return false;
        }
        if (!entity.method_5685().isEmpty()) {
            return false;
        }
        return entity instanceof EntityChair || entity instanceof class_1690;
    }

    private class_6670 getEntities(EntityMaid maid) {
        return maid.method_18868().method_18904(class_4140.field_18442).orElse(class_6670.method_38971());
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.7.1-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/entity/ai/brain/task/MaidFindSitTask.java <==
package com.github.tartaricacid.touhoulittlemaid.entity.ai.brain.task;

import com.github.tartaricacid.touhoulittlemaid.entity.item.EntityChair;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.google.common.collect.ImmutableMap;
import net.minecraft.class_1297;
import net.minecraft.class_1690;
import net.minecraft.class_3218;
import net.minecraft.class_4140;
import net.minecraft.class_4141;
import net.minecraft.class_4215;
import net.minecraft.class_6670;

public class MaidFindSitTask extends MaidCheckRateTask {
    private static final int MAX_DELAY_TIME = 12;
    private final float speedModifier;
    private class_1297 sitEntity = null;
    private long chatBubbleKey = -1;

    public MaidFindSitTask(float speedModifier) {
        super(ImmutableMap.of(class_4140.field_18442, class_4141.field_18456,
                class_4140.field_18445, class_4141.field_18457));
        this.speedModifier = speedModifier;
        this.setMaxCheckRate(MAX_DELAY_TIME);
    }

    @Override
    protected boolean checkExtraStartConditions(class_3218 worldIn, EntityMaid owner) {
        return super.checkExtraStartConditions(worldIn, owner) && owner.method_5854() == null;
    }

    @Override
    protected void start(class_3218 worldIn, EntityMaid maid, long gameTimeIn) {
        this.sitEntity = null;
        this.getEntities(maid)
                .method_38980(e -> filterEntity(maid, e))
                .findFirst()
                .ifPresentOrElse(entity -> {
                    this.sitEntity = entity;
                    class_4215.method_24557(maid, this.sitEntity, this.speedModifier, 0);
                }, () -> {
                    String langKey = "chat_bubble.touhou_little_maid.inner.fishing.no_sit";
                    this.chatBubbleKey = maid.getChatBubbleManager().addTextChatBubbleIfTimeout(langKey, this.chatBubbleKey);
                });

        if (sitEntity != null && sitEntity.method_5805() && sitEntity.method_24516(maid, 2)) {
            if (sitEntity.method_5685().isEmpty()) {
                maid.method_5873(this.sitEntity, true);
            }
            this.sitEntity = null;
        }
    }

    private boolean filterEntity(EntityMaid maid, class_1297 entity) {
        if (!entity.method_5805()) {
            return false;
        }
        if (!maid.method_18407(entity.method_24515())) {
            return false;
        }
        if (!entity.method_5685().isEmpty()) {
            return false;
        }
        return entity instanceof EntityChair || entity instanceof class_1690;
    }

    private class_6670 getEntities(EntityMaid maid) {
        return maid.method_18868().method_18904(class_4140.field_18442).orElse(class_6670.method_38971());
    }
}
